==> attal_0.8.orig.tar.gz: attal-0.8/i18n/de/attal_server_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>ChooseFileRadioButton</name>
    <message>
        <source>Choose</source>
        <translation>Suchen</translation>
    </message>
</context>
<context>
    <name>ConfigConnection</name>
    <message>
        <source>Start server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished">Starten</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation type="unfinished">Beenden</translation>
    </message>
</context>
<context>
    <name>Engine</name>
    <message>
        <source>Error with scenario</source>
        <translation>Fehler im Szenario</translation>
    </message>
    <message>
        <source>Wrong number of connected players</source>
        <translation>Die Zahl der verbundenen Spieler stimmt nicht mit dem Szenario überein</translation>
    </message>
</context>
<context>
    <name>ServerInterface</name>
    <message>
        <source>Attal - Lords of Doom (Server)</source>
        <translation>Attal - Lords of Doom (Server)</translation>
    </message>
    <message>
        <source>Server error</source>
        <translation>Server-Fehler</translation>
    </message>
    <message>
        <source>Could not listen for sockets.</source>
        <translation>Es können keine Sockets benutzt werden. </translation>
    </message>
    <message>
        <source>Try again</source>
        <translation>Wiederholen</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Statusleiste</translation>
    </message>
    <message>
        <source>Load Game</source>
        <translation>Spielstand laden</translation>
    </message>
    <message>
        <source>Save Game</source>
        <translation>Spielstand speichern</translation>
    </message>
    <message>
        <source>End Game</source>
        <translation>Spiel beenden</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
</context>
<context>
    <name>ServerWidget</name>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Starten</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Spielende</translation>
    </message>
</context>
</TS>

==> attal_0.9.1.orig.tar.gz: attal-0.9.1/i18n/de/attal_server_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>ChooseFileRadioButton</name>
    <message>
        <source>Choose</source>
        <translation>Suchen</translation>
    </message>
</context>
<context>
    <name>ConfigConnection</name>
    <message>
        <source>Start server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished">Starten</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation type="unfinished">Beenden</translation>
    </message>
</context>
<context>
    <name>DisplayScenarii</name>
    <message>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Players</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished">Name</translation>
    </message>
</context>
<context>
    <name>DisplayScenariiDialog</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DisplayScenarioDescription</name>
    <message>
        <source>Name: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Player(s): %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size: %1x%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Player(s): </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Engine</name>
    <message>
        <source>Error with scenario</source>
        <translation>Fehler im Szenario</translation>
    </message>
    <message>
        <source>Wrong number of connected players</source>
        <translation>Die Zahl der verbundenen Spieler stimmt nicht mit dem Szenario überein</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ServerInterface</name>
    <message>
        <source>Attal - Lords of Doom (Server)</source>
        <translation>Attal - Lords of Doom (Server)</translation>
    </message>
    <message>
        <source>Server error</source>
        <translation>Server-Fehler</translation>
    </message>
    <message>
        <source>Could not listen for sockets.</source>
        <translation>Es können keine Sockets benutzt werden. </translation>
    </message>
    <message>
        <source>Try again</source>
        <translation>Wiederholen</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Statusleiste</translation>
    </message>
    <message>
        <source>Load Game</source>
        <translation type="obsolete">Spielstand laden</translation>
    </message>
    <message>
        <source>Save Game</source>
        <translation type="obsolete">Spielstand speichern</translation>
    </message>
    <message>
        <source>End Game</source>
        <translation type="obsolete">Spiel beenden</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <source>Can&apos;t load theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> has not been loaded successfully</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load scenario</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load campaign</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fill with AI</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add AI player</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ServerWidget</name>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Starten</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Spielende</translation>
    </message>
</context>
</TS>
